@@ -1,6 +1,16 @@
 #
 # This file will have to be sourced where needed
-#
+
+# To prevent sourcing this file twice when using scripts to build CD images,
+# use the following code at the top of your script:
+#    CF=CONF.sh
+#    . $CF
+#    export DEBIAN_CD_CONF_SOURCED=true
+
+# Allow to prevent double sourcing of this file
+if [ "$DEBIAN_CD_CONF_SOURCED" = true ]; then
+	return 0
+fi
 
 # Unset all optional variables first to start from a clean state
 unset NONFREE           || true
@@ -35,6 +45,7 @@ unset MAXCDS            || true
 unset SPLASHPNG         || true
 unset OMIT_MANUAL	 || true
 unset OMIT_RELEASE_NOTES || true
+unset OMIT_DOC_TOOLS     || true
 
 # The debian-cd dir
 # Where I am (hoping I'm in the debian-cd dir)
@@ -55,7 +66,7 @@ fi
 #export DI_WWW_HOME=default
 
 # Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="4.0"
+export DEBVERSION="5.0"
 
 # Official or non-official set.
 # NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -266,18 +277,21 @@ done
 # File with list of packages to exclude as above.
 #export BASE_EXCLUDE="$BASEDIR"/data/$CODENAME/base_exclude
 
-# Only put the installer onto the cd (set NORECOMMENDS,... as well).
+# Only put the installer onto the cd (set NORECOMMENDS,... as well,
+# and if you're not using build.sh then also make sure you set TASK
+# appropriately here)
 # INSTALLER_CD=0: nothing special (default)
 # INSTALLER_CD=1: just add debian-installer (use TASK=tasks/debian-installer-$CODENAME)
 # INSTALLER_CD=2: add d-i and base (use TASK=tasks/debian-installer+kernel-$CODENAME)
 #export INSTALLER_CD=2
+#export TASK=tasks/debian-installer+kernel-$CODENAME
 
 # Parameters to pass to kernel (or d-i) when the CD boots. Not currently
 # supported for all architectures.
 #export KERNEL_PARAMS="DEBCONF_PRIORITY=critical"
 
 # If set, limits the number of binary CDs to produce.
-export MAXCDS=1
+#export MAXCDS=1
 
 # If set, overrides the boot picture used.
 #export SPLASHPNG="$BASEDIR/data/$CODENAME/splash-img.png"
@@ -290,6 +304,11 @@ export MAXCDS=1
 # If so we will link to them on the web site.
 export OMIT_RELEASE_NOTES=1
 
+# Set to 1 to not include the doc/tools directories on CD1
+# Useful to save space and avoids failures if you have a mirror
+# without those directories.
+#export OMIT_DOC_TOOLS=1
+
 # Set this to override the default location
 #export RELEASE_NOTES_LOCATION="http://www.debian.org/releases/$CODENAME"
 
