@@ -45,7 +45,7 @@ my $list = "$tdir/list";
 my $list_ex = "$tdir/list.exclude";
 my $bdir = "$tdir/$codename";
 my $log = "$bdir/make_disc_tree.log";
-open(LOG, ">> $log") || die ("Can't open logfile $log for writing: $!\n");
+open(LOG, ">> $log") or die ("Can't open logfile $log for writing: $!\n");
 
 foreach my $arch (split(' ', $archlist)) {
 	push(@arches, $arch);
@@ -113,7 +113,7 @@ if ($archlist =~ /m68k/ || $archlist =~ /powerpc/) {
 
 print "Starting to lay out packages into $disktype ($diskdesc) images: $maxdiskblocks 2K-blocks maximum per image\n";
 
-open(INLIST, "$bdir/packages") || die "No packages file!\n";
+open(INLIST, "$bdir/packages") or die "No packages file!\n";
 while (defined (my $pkg = <INLIST>)) {
 	chomp $pkg;
 	$cddir = "$bdir/CD$disknum";
@@ -270,11 +270,11 @@ sub should_exclude_package {
     my $should_exclude = 0;
 
     foreach my $entry (@exclude_packages) {
-	    if (($pkgname =~ /^\Q$entry\E$/m)) {
+	if (($pkgname =~ /^\Q$entry\E$/m)) {
             print LOG "Excluding $pkg due to match on \"\^$entry\$\"\n";
             $should_exclude++;
         }
-	}
+    }
 
     if ($should_exclude) {
         # Double-check that we're not being asked to include *and*
@@ -308,14 +308,14 @@ sub check_base_installable {
 	}
 	close PLIST;
 
-    $packages_file = "$cddir/dists/$codename/local/binary-$arch/Packages";
-    if (open (PLIST, $packages_file)) {
-        while (defined($p = <PLIST>)) {
-            chomp $p;
-            $p =~ m/^Package: (\S+)/ and $on_disc{$1} = $1;
-        }
-        close PLIST;
-    }
+	$packages_file = "$cddir/dists/$codename/local/binary-$arch/Packages";
+	if (open (PLIST, $packages_file)) {
+		while (defined($p = <PLIST>)) {
+			chomp $p;
+			$p =~ m/^Package: (\S+)/ and $on_disc{$1} = $1;
+		}
+		close PLIST;
+	}
 
 	if (defined($ENV{'BASE_EXCLUDE'})) {
 		open (ELIST, $ENV{'BASE_EXCLUDE'})
@@ -347,6 +347,24 @@ sub check_base_installable {
 	return $ok;
 }
 
+# If missing, create an empty local Packages file for an architecture.
+# Only create an uncompressed Packages file; the call to recompress will
+# create the compressed version.
+sub add_missing_Packages {
+	my ($filename);
+
+	$filename = $File::Find::name;
+
+	if ((-d "$_") && ($filename =~ m/\/main\/binary-[^\/]*$/)) {
+		if ((-f "$_/Packages") && (! -d "../local/$_/")) {
+			mkdir "../local/$_/" || die "Error creating directory local/$_: $!\n";
+			open(LPFILE, ">../local/$_/Packages") or die "Error creating local/$_/Packages: $!\n";
+			close LPFILE;
+			print "  Created empty Packages file for local/$_\n";
+		}
+	}
+}
+
 sub md5_file {
 	my $filename = shift;
 	my ($md5, $st);
@@ -500,15 +518,15 @@ sub finish_disc {
 	my $ok = 0;
 	my $bytes = 0;
 	my $ctx;
-    my $hook;
+	my $hook;
 	my $error = 0;
 
-    if (defined($ENV{'DISC_FINISH_HOOK'})) {
-        $hook = $ENV{'DISC_FINISH_HOOK'};
-        print "  Calling disc_finish hook: $hook\n";
-        $error = system("$hook $tdir $mirror $disknum $cddir \"$archlist\"");
+	if (defined($ENV{'DISC_FINISH_HOOK'})) {
+		$hook = $ENV{'DISC_FINISH_HOOK'};
+		print "  Calling disc_finish hook: $hook\n";
+		$error = system("$hook $tdir $mirror $disknum $cddir \"$archlist\"");
 		$error == 0 || die "DISC_FINISH_HOOK failed with error $error\n";
-    }
+	}
 
 	if (($disknum == 1) && !($archlist eq "source") && !($disktype eq "BC")) {
 		foreach my $arch (@arches_nosrc) {
@@ -532,9 +550,18 @@ sub finish_disc {
 
 	chdir $cddir;
 
+	# If we have a local packages directory, ensure we have a Packages file
+	# for all included architectures as otherwise the Release file will be
+	# invalid. This can happen if we do have local udebs but no local
+	# regular packages, or multiple architectures with not all of them
+	# having local packages.
+	if (-d "./dists/$codename/local") {
+		find (\&add_missing_Packages, "./dists/$codename/main/");
+	}
+
 	print "  Finishing off the Release file\n";
 	chdir "dists/$codename";
-	open(RELEASE, ">>Release") || die "Failed to open Release file: $!\n";
+	open(RELEASE, ">>Release") or die "Failed to open Release file: $!\n";
 	print RELEASE "MD5Sum:\n";
 	find (\&recompress, ".");
 	find (\&md5_files_for_release, ".");
@@ -543,7 +570,7 @@ sub finish_disc {
 
 	print "  Finishing off md5sum.txt\n";
 	# Just md5 the bits we won't have seen already
-	open(MD5LIST, ">>md5sum.txt") || die "Failed to open md5sum.txt file: $!\n";
+	open(MD5LIST, ">>md5sum.txt") or die "Failed to open md5sum.txt file: $!\n";
 	find (\&md5_files_for_md5sum, ("./.disk", "./dists"));
 	close(MD5LIST);
 
@@ -553,12 +580,12 @@ sub finish_disc {
 	system("mv -f md5sum.txt.tmp md5sum.txt");
 	chdir $bdir;
 
-    if (defined($ENV{'DISC_END_HOOK'})) {
-        $hook = $ENV{'DISC_END_HOOK'};
-        print "  Calling disc_end hook: $hook\n";
-        $error = system("$hook $tdir $mirror $disknum $cddir \"$archlist\"");
+	if (defined($ENV{'DISC_END_HOOK'})) {
+		$hook = $ENV{'DISC_END_HOOK'};
+		print "  Calling disc_end hook: $hook\n";
+		$error = system("$hook $tdir $mirror $disknum $cddir \"$archlist\"");
 		$error == 0 || die "DISC_END_HOOK failed with error $error\n";
-    }
+	}
 
 	$size = `$size_check $cddir`;
 	chomp $size;
